@@ -6,9 +6,11 @@ from . import (
     googlenet,
     mobilenetv2,
     mobilenetv3,
+    regnet,
     resnet,
     shufflenetv2,
     squeezenet,
+    swin,
     vgg,
     vit,
 )
