@@ -7,9 +7,9 @@ import jax
 import jax.nn as jnn
 import jax.numpy as jnp
 import jax.random as jrandom
-from equinox.custom_types import Array
+from jaxtyping import Array
 
-from ...utils import load_torch_weights, MODEL_URLS
+from ...utils import load_torch_weights
 
 
 class GoogLeNet(eqx.Module):
@@ -310,25 +310,25 @@ class BasicConv2d(eqx.Module):
         return jnn.relu(x)
 
 
-def googlenet(pretrained=False, **kwargs: Any) -> GoogLeNet:
+def googlenet(torch_weights: str = None, **kwargs: Any) -> GoogLeNet:
     r"""GoogLeNet (Inception v1) model architecture from
     [Going Deeper with Convolutions](http://arxiv.org/abs/1409.4842).
     The required minimum input size of the model is 15x15.
 
     **Arguments:**
 
-    - `pretrained`: If `True`, the weights are loaded from `PyTorch` saved checkpoint.
+    - `torch_weights`: A `Path` or `URL` for the `PyTorch` weights. Defaults to `None`
 
     """
-    if pretrained:
+    if torch_weights:
         use_aux = kwargs.get("aux_logits", False)
         model = GoogLeNet(aux_logits=True, **kwargs)
-        model = load_torch_weights(model, url=MODEL_URLS["googlenet"])
+        model = load_torch_weights(model, torch_weights=torch_weights)
         if not use_aux:
             model = eqx.tree_at(lambda m: m.aux_logits, model, replace=(False))
         else:
             warnings.warn(
-                "Loaded pretrained weights for GoogLeNet. But, aux-branch weights are un-trained."
+                "Loaded torch_weights weights for GoogLeNet. But, aux-branch weights are un-trained."
             )
     else:
         model = GoogLeNet(**kwargs)
