@@ -2,7 +2,6 @@ import logging
 import os
 import sys
 import warnings
-from pathlib import Path
 from typing import NewType, Optional
 
 import equinox as eqx
@@ -17,7 +16,13 @@ except ImportError:
 
 _TEMP_DIR = "/tmp/.eqx"
 _Url = NewType("_Url", str)
-MODEL_URLS = {
+
+SEGMENTATION_URLS = {
+    "fcn_resnet50": "https://download.pytorch.org/models/fcn_resnet50_coco-1167a1af.pth",
+    "deeplabv3_resnet50": "https://download.pytorch.org/models/deeplabv3_resnet50_coco-cd0a2569.pth",
+}
+
+CLASSIFICATION_URLS = {
     "alexnet": "https://download.pytorch.org/models/alexnet-owt-7be5be79.pth",
     "convnext_tiny": "https://download.pytorch.org/models/convnext_tiny-983f1562.pth",
     "convnext_small": "https://download.pytorch.org/models/convnext_small-0c510722.pth",
@@ -66,8 +71,6 @@ MODEL_URLS = {
     "resnext101_32x8d": "https://download.pytorch.org/models/resnext101_32x8d-8ba56ff5.pth",
     "shufflenetv2_x0.5": "https://download.pytorch.org/models/shufflenetv2_x0.5-f707e7126e.pth",
     "shufflenetv2_x1.0": "https://download.pytorch.org/models/shufflenetv2_x1-5666bf0f80.pth",
-    "shufflenetv2_x1.5": None,
-    "shufflenetv2_x2.0": None,
     "squeezenet1_0": "https://download.pytorch.org/models/squeezenet1_0-b66bff10.pth",
     "squeezenet1_1": "https://download.pytorch.org/models/squeezenet1_1-b8a52dc0.pth",
     "swin_t": "https://download.pytorch.org/models/swin_t-704ceda3.pth",
@@ -97,8 +100,25 @@ MODEL_URLS = {
 }
 
 
+def _make_divisible(v: float, divisor: int, min_value: Optional[int] = None) -> int:
+    """
+    This function is taken from the original tf repo.
+    It ensures that all layers have a channel number that is divisible by 8
+    It can be seen here:
+    https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet/mobilenet.py
+    """
+    if min_value is None:
+        min_value = divisor
+    new_v = max(min_value, int(v + divisor / 2) // divisor * divisor)
+    # Make sure that round down does not go down by more than 10%.
+    if new_v < 0.9 * v:
+        new_v += divisor
+    return new_v
+
+
 def load_torch_weights(
-    model: eqx.Module, filepath: Path = None, url: "_Url" = None
+    model: eqx.Module,
+    torch_weights: str = None,
 ) -> eqx.Module:
     """Loads weights from a PyTorch serialised file.
 
@@ -112,12 +132,15 @@ def load_torch_weights(
           attributes mirrors the `torchvision.models` implementation.
         - The saved checkpoint should **only** contain model parameters as keys.
 
+    !!! info
+        A full list of pretrained URLs is provided
+        [here](https://github.com/paganpasta/eqxvision/blob/main/eqxvision/utils.py).
+
     **Arguments:**
 
-    - model: An `eqx.Module` for which the `jnp.ndarray` leaves are
+    - `model`: An `eqx.Module` for which the `jnp.ndarray` leaves are
         replaced by corresponding `PyTorch` weights.
-    - filepath: `Path` to the downloaded `PyTorch` model file.
-    - url: `URL` for the `PyTorch` model file. The file is downloaded to `/tmp/.eqx/` folder.
+    - `torch_weights`: A string either pointing to `PyTorch` weights on disk or the download `URL`.
 
     **Returns:**
         The model with weights loaded from the `PyTorch` checkpoint.
@@ -127,35 +150,32 @@ def load_torch_weights(
             " Torch package not found! Pretrained is only supported with the torch package."
         )
 
-    if filepath is None and url is None:
-        raise ValueError("Both filepath and url cannot be empty!")
-    elif filepath and url:
-        warnings.warn(f"Overriding `url` with with filepath: {filepath}.")
-        url = None
-    if url:
+    if torch_weights is None:
+        raise ValueError("torch_weights parameter cannot be empty!")
+
+    if not os.path.exists(torch_weights):
         global _TEMP_DIR
-        filepath = os.path.join(_TEMP_DIR, os.path.basename(url))
+        filepath = os.path.join(_TEMP_DIR, os.path.basename(torch_weights))
         if os.path.exists(filepath):
             logging.info(
                 f"Downloaded file exists at f{filepath}. Using the cached file!"
             )
         else:
             os.makedirs(_TEMP_DIR, exist_ok=True)
-            torch.hub.download_url_to_file(url, filepath)
-    if not os.path.exists(filepath):
-        raise ValueError(f"filepath: {filepath} does not exist!")
-
-    weights = torch.load(filepath, map_location="cpu")
+            torch.hub.download_url_to_file(torch_weights, filepath)
+    else:
+        filepath = torch_weights
+    saved_weights = torch.load(filepath, map_location="cpu")
     weights_iterator = iter(
         [
             (name, jnp.asarray(weight.detach().numpy()))
-            for name, weight in weights.items()
+            for name, weight in saved_weights.items()
             if "running" not in name and "num_batches" not in name
         ]
     )
 
     bn_s = []
-    for name, weight in weights.items():
+    for name, weight in saved_weights.items():
         if "running_mean" in name:
             bn_s.append(False)
             bn_s.append(jnp.asarray(weight.detach().numpy()))
@@ -194,19 +214,3 @@ def load_torch_weights(
 
     model = jtu.tree_map(set_experimental, bn_iterator, model)
     return model
-
-
-def _make_divisible(v: float, divisor: int, min_value: Optional[int] = None) -> int:
-    """
-    This function is taken from the original tf repo.
-    It ensures that all layers have a channel number that is divisible by 8
-    It can be seen here:
-    https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet/mobilenet.py
-    """
-    if min_value is None:
-        min_value = divisor
-    new_v = max(min_value, int(v + divisor / 2) // divisor * divisor)
-    # Make sure that round down does not go down by more than 10%.
-    if new_v < 0.9 * v:
-        new_v += divisor
-    return new_v
